@@ -1,4 +1,4 @@
-from rox.core.entities.variant import Variant
+from rox.core.entities.rox_base import RoxBase
 
 
 class Registerer:
@@ -11,10 +11,11 @@ class Registerer:
             raise TypeError('A namespace cannot be null')
 
         if ns in self.namespaces:
-            raise ValueError('A container with the given namespace (%s) has already been registered' % ns)
+            error_message = 'A container with the given namespace ({}) has already been registered'.format(ns)
+            raise ValueError(error_message)
 
         self.namespaces.add(ns)
 
         for name, value in vars(container).items():
-            if isinstance(value, Variant):
+            if isinstance(value, RoxBase):
                 self.flag_repository.add_flag(value, name if ns == '' else '%s.%s' % (ns, name))
